@@ -19,6 +19,7 @@ RE_STATUS = re.compile("<lsPower .*? state=\"(.*?)\"", re.IGNORECASE)
 RE_GET_DN = re.compile(" dn=\"(.*?)\"", re.IGNORECASE)
 RE_GET_PNDN = re.compile(" pndn=\"(.*?)\"", re.IGNORECASE)
 RE_GET_DESC = re.compile(" descr=\"(.*?)\"", re.IGNORECASE)
+RE_GET_OPERPOWER = re.compile(" operPower=\"(.*?)\"", re.IGNORECASE)
 RE_GET_PRESENCE = re.compile(" presence=\"(.*?)\"", re.IGNORECASE)
 
 options_global = None
@@ -50,12 +51,21 @@ def get_power_status(conn, options):
 	if result == None:
 		fail(EC_STATUS)
 	else:
-		status = result.group(1)
+		presence_status = result.group(1)
 
-	if status in ["missing", "mismatch"]:
+	if presence_status in ["missing", "mismatch"]:
 		return "off"
 	else:
-		return "on"
+		result = RE_GET_OPERPOWER.search(res)
+		if result == None:
+			fail(EC_STATUS)
+		else:
+			power_status = result.group(1)
+
+		if power_status == "on":
+			return "on"
+		else:
+			return "off"
 
 def set_power_status(conn, options):
 	del conn
@@ -104,7 +114,7 @@ def send_command(opt, command, timeout):
 
 	## send command through pycurl
 	conn = pycurl.Curl()
-	web_buffer = io.StringIO()
+	web_buffer = io.BytesIO()
 	conn.setopt(pycurl.URL, url)
 	conn.setopt(pycurl.HTTPHEADER, ["Content-type: text/xml"])
 	conn.setopt(pycurl.POSTFIELDS, command)
@@ -118,7 +128,7 @@ def send_command(opt, command, timeout):
 		conn.setopt(pycurl.SSL_VERIFYPEER, 0)
 		conn.setopt(pycurl.SSL_VERIFYHOST, 0)
 	conn.perform()
-	result = web_buffer.getvalue()
+	result = web_buffer.getvalue().decode()
 
 	logging.debug("%s\n", command)
 	logging.debug("%s\n", result)
