@@ -64,6 +64,7 @@ all_opt = {
 	"delay" : {
 		"getopt" : ":",
 		"longopt" : "delay",
+		"type" : "second",
 		"help" : "--delay=[seconds]              Wait X seconds before fencing is started",
 		"required" : "0",
 		"default" : "0",
@@ -101,6 +102,7 @@ all_opt = {
 	"ipport" : {
 		"getopt" : "u:",
 		"longopt" : "ipport",
+		"type" : "integer",
 		"help" : "-u, --ipport=[port]            TCP/UDP port to use for connection",
 		"required" : "0",
 		"shortdesc" : "TCP/UDP port to use for connection with device",
@@ -317,6 +319,7 @@ all_opt = {
 	"login_timeout" : {
 		"getopt" : ":",
 		"longopt" : "login-timeout",
+		"type" : "second",
 		"help" : "--login-timeout=[seconds]      Wait X seconds for cmd prompt after login",
 		"default" : "5",
 		"required" : "0",
@@ -324,6 +327,7 @@ all_opt = {
 	"shell_timeout" : {
 		"getopt" : ":",
 		"longopt" : "shell-timeout",
+		"type" : "second",
 		"help" : "--shell-timeout=[seconds]      Wait X seconds for cmd prompt after issuing command",
 		"default" : "3",
 		"required" : "0",
@@ -331,6 +335,7 @@ all_opt = {
 	"power_timeout" : {
 		"getopt" : ":",
 		"longopt" : "power-timeout",
+		"type" : "second",
 		"help" : "--power-timeout=[seconds]      Test X seconds for status change after ON/OFF",
 		"default" : "20",
 		"required" : "0",
@@ -338,6 +343,7 @@ all_opt = {
 	"power_wait" : {
 		"getopt" : ":",
 		"longopt" : "power-wait",
+		"type" : "second",
 		"help" : "--power-wait=[seconds]         Wait X seconds after issuing ON/OFF",
 		"default" : "0",
 		"required" : "0",
@@ -351,6 +357,7 @@ all_opt = {
 	"retry_on" : {
 		"getopt" : ":",
 		"longopt" : "retry-on",
+		"type" : "integer",
 		"help" : "--retry-on=[attempts]          Count of attempts to retry power on",
 		"default" : "1",
 		"required" : "0",
@@ -438,13 +445,20 @@ all_opt = {
 	"on_target": {
 		"getopt" : "",
 		"help" : "",
-		"order" : 1}
+		"order" : 1},
+	"quiet": {
+		"getopt" : "q",
+		"longopt": "quiet",
+		"help" : "-q, --quiet                    Disable logging to stderr. Does not affect --verbose or --debug logging to syslog.",
+		"required" : "0",
+		"order" : 50}
 }
 
 # options which are added automatically if 'key' is encountered ("default" is always added)
 DEPENDENCY_OPT = {
 		"default" : ["help", "debug", "verbose", "version", "action", "agent", \
-			"power_timeout", "shell_timeout", "login_timeout", "power_wait", "retry_on", "delay"],
+			"power_timeout", "shell_timeout", "login_timeout", "power_wait", "retry_on", \
+			"delay", "quiet"],
 		"passwd" : ["passwd_script"],
 		"sudo" : ["sudo_path"],
 		"secure" : ["identity_file", "ssh_options", "ssh_path"],
@@ -575,7 +589,8 @@ def metadata(avail_opt, docs):
 					print("\t\t\t<option value=\"%s\" />" % (choice))
 				print("\t\t</content>")
 			elif all_opt[option]["getopt"].count(":") > 0:
-				print("\t\t<content type=\"string\" "+default+" />")
+				t = all_opt[option].get("type", "string")
+				print("\t\t<content type=\"%s\" " % (t) +default+" />")
 			else:
 				print("\t\t<content type=\"boolean\" "+default+" />")
 			print("\t\t<shortdesc lang=\"en\">" + shortdesc + "</shortdesc>")
@@ -644,8 +659,9 @@ def check_input(device_opt, opt, other_conditions = False):
 
 	## add logging to syslog
 	logging.getLogger().addHandler(SyslogLibHandler())
-	## add logging to stderr
-	logging.getLogger().addHandler(logging.StreamHandler(stream=sys.stderr))
+	if "--quiet" not in options:
+		## add logging to stderr
+		logging.getLogger().addHandler(logging.StreamHandler(sys.stderr))
 
 	(acceptable_actions, _) = _get_available_actions(device_opt)
 
@@ -903,17 +919,13 @@ def is_executable(path):
 			return True
 	return False
 
-def run_command(options, command, timeout=None, env=None):
+def run_command(options, command, timeout=None, env=None, log_command=None):
 	if timeout is None and "--power-timeout" in options:
 		timeout = options["--power-timeout"]
 	if timeout is not None:
 		timeout = float(timeout)
 
-	# For IPMI password occurs on command line, it should not be part of debug info
-	log_command = command
-	if "ipmitool" in log_command:
-		log_command = re.sub("-P (.+?) -p", "-P [set] -p", log_command)
-	logging.info("Executing: %s\n", log_command)
+	logging.info("Executing: %s\n", log_command or command)
 
 	try:
 		process = subprocess.Popen(shlex.split(command), stdout=subprocess.PIPE, stderr=subprocess.PIPE, env=env)
@@ -1249,6 +1261,15 @@ def _validate_input(options, stop = True):
 		fail_usage("Failed: You have to enter a valid choice for %s from the valid values: %s" % \
 			("--" + all_opt[failed_opt]["longopt"], str(all_opt[failed_opt]["choices"])), stop)
 
+	for failed_opt in _get_opts_with_invalid_types(options):
+		valid_input = False
+		if all_opt[failed_opt]["type"] == "second":
+			fail_usage("Failed: The value you have entered for %s is not a valid time in seconds" % \
+				("--" + all_opt[failed_opt]["longopt"]), stop)
+		else:
+			fail_usage("Failed: The value you have entered for %s is not a valid %s" % \
+				("--" + all_opt[failed_opt]["longopt"], all_opt[failed_opt]["type"]), stop)
+
 	return valid_input
 
 def _encode_html_entities(text):
@@ -1360,6 +1381,21 @@ def _get_opts_with_invalid_choices(options):
 					options_failed.append(opt)
 	return options_failed
 
+def _get_opts_with_invalid_types(options):
+	options_failed = []
+	device_opt = options["device_opt"]
+
+	for opt in device_opt:
+		if "type" in all_opt[opt]:
+			longopt = "--" + all_opt[opt]["longopt"]
+			if longopt in options:
+				if all_opt[opt]["type"] in ["integer", "second"]:
+					try:
+						number = int(options["--" + all_opt[opt]["longopt"]])
+					except ValueError:
+						options_failed.append(opt)
+	return options_failed
+
 def _verify_unique_getopt(avail_opt):
 	used_getopt = set()
 
