@@ -157,7 +157,7 @@ def main():
 	atexit.register(atexit_handler)
 
 	all_opt["ipport"]["default"] = "44444"
-	all_opt["shell_timeout"]["default"] = "5.0"
+	all_opt["shell_timeout"]["default"] = "5"
 	all_opt["missing_as_off"]["default"] = "1"
 	options = check_input(device_opt, process_input(device_opt), other_conditions=True)
 
